pub struct EventGridStreamInputDataSourceProperties {
pub subscriber: Option<EventHubV2StreamInputDataSource>,
pub schema: Option<EventGridEventSchemaType>,
pub storage_accounts: Vec<StorageAccount>,
pub event_types: Vec<String>,
}Expand description
The properties that are associated with an event grid input containing stream data.
Fields
subscriber: Option<EventHubV2StreamInputDataSource>Describes an Event Hub input data source that contains stream data.
schema: Option<EventGridEventSchemaType>Supported Event Grid schema types.
storage_accounts: Vec<StorageAccount>A list of one or more Azure Storage accounts. Required on PUT (CreateOrReplace) requests.
event_types: Vec<String>List of Event Types that are supported by the Event Grid adapter.
Implementations