pub struct SampleInput {
pub input: Option<Input>,
pub compatibility_level: Option<String>,
pub events_uri: Option<String>,
pub data_locale: Option<String>,
}Expand description
The stream analytics input to sample.
Fields
input: Option<Input>An input object, containing all information associated with the named input. All inputs are contained under a streaming job.
compatibility_level: Option<String>Defaults to the default ASA job compatibility level. Today it is 1.2
events_uri: Option<String>The SAS URI of the storage blob for service to write the sampled events to. If this parameter is not provided, service will write events to he system account and share a temporary SAS URI to it.
data_locale: Option<String>Defaults to en-US.
Implementations
Sourceimpl SampleInput
impl SampleInput