pub enum OutputErrorPolicy {
Stop,
Drop,
UnknownValue(String),
}Expand description
Indicates the policy to apply to events that arrive at the output and cannot be written to the external storage due to being malformed (missing column values, column values of wrong type or size).
Variants
Implementations
Sourceimpl OutputErrorPolicy
impl OutputErrorPolicy
pub fn serialize<__S>(
__self: &OutputErrorPolicy,
__serializer: __S,
) -> Result<__S::Ok, __S::Error>where
__S: Serializer,
Sourceimpl<'de> OutputErrorPolicy
impl<'de> OutputErrorPolicy
pub fn deserialize<__D>(
__deserializer: __D,
) -> Result<OutputErrorPolicy, __D::Error>where
__D: Deserializer<'de>,