pub struct EventHubStreamInputDataSourceProperties {
pub event_hub_data_source_properties: EventHubDataSourceProperties,
pub consumer_group_name: Option<String>,
}Expand description
The properties that are associated with a Event Hub input containing stream data.
Fields
event_hub_data_source_properties: EventHubDataSourcePropertiesconsumer_group_name: Option<String>The name of an Event Hub Consumer Group that should be used to read events from the Event Hub. Specifying distinct consumer group names for multiple inputs allows each of those inputs to receive the same events from the Event Hub. If not specified, the input uses the Event Hub’s default consumer group.
Implementations