pub struct EventHubV2StreamInputDataSource {
pub properties: Option<EventHubStreamInputDataSourceProperties>,
}Expand description
Describes an Event Hub input data source that contains stream data.
Fields
properties: Option<EventHubStreamInputDataSourceProperties>The properties that are associated with a Event Hub input containing stream data.
Implementations