pub struct PowerBiOutputDataSourceProperties {
pub o_auth_based_data_source_properties: OAuthBasedDataSourceProperties,
pub dataset: Option<String>,
pub table: Option<String>,
pub group_id: Option<String>,
pub group_name: Option<String>,
pub authentication_mode: Option<AuthenticationMode>,
}Expand description
The properties that are associated with a Power BI output.
Fields
o_auth_based_data_source_properties: OAuthBasedDataSourcePropertiesdataset: Option<String>The name of the Power BI dataset. Required on PUT (CreateOrReplace) requests.
table: Option<String>The name of the Power BI table under the specified dataset. Required on PUT (CreateOrReplace) requests.
group_id: Option<String>The ID of the Power BI group.
group_name: Option<String>The name of the Power BI group. Use this property to help remember which specific Power BI group id was used.
authentication_mode: Option<AuthenticationMode>Authentication Mode. Valid modes are ConnectionString, Msi and ‘UserToken’.
Implementations