pub struct AzureMachineLearningWebServiceInputs {
pub name: Option<String>,
pub column_names: Vec<AzureMachineLearningWebServiceInputColumn>,
}Expand description
The inputs for the Azure Machine Learning web service endpoint.
Fields
name: Option<String>The name of the input. This is the name provided while authoring the endpoint.
column_names: Vec<AzureMachineLearningWebServiceInputColumn>A list of input columns for the Azure Machine Learning web service endpoint.
Implementations